@@ -25,13 +25,4 @@ async def init_models() -> None:
 # Dependency
 async def get_session() -> AsyncGenerator:  # type: ignore
     async with async_session() as session:
-        yield session
-
-
-class User(SQLAlchemyBaseUserTableUUID, Base):
-    pass
-
-
-async def get_user_db(
-        session: AsyncSession = Depends(get_session)) -> AsyncGenerator:  # type: ignore
-    yield SQLAlchemyUserDatabase(session, User)
+        yield session
\ No newline at end of file
